@@ -529,10 +529,9 @@ Region region;
  *
  ***********************************************************************/
 
-static void _Reposition(lw, width, height, dx, dy)
+static void _Reposition(lw, width, height)
 register LabelWidget lw;
 Dimension width, height;
-Position *dx, *dy;
 {
     Position newPos;
     Position leftedge = lw->label.internal_width + LEFT_OFFSET(lw);
@@ -552,13 +551,9 @@ Position *dx, *dy;
 	    newPos = (int)(width - lw->label.label_width) / 2;
 	    break;
     }
-    if (newPos < (Position)leftedge)
-	newPos = leftedge;
-    *dx = newPos - lw->label.label_x;
+    if (newPos < (Position)leftedge) newPos = leftedge;
     lw->label.label_x = newPos;
-    *dy = (newPos = (int)(height - lw->label.label_height) / 2)
-	  - lw->label.label_y;
-    lw->label.label_y = newPos;
+    lw->label.label_y = (int)(height - lw->label.label_height)/2;
     return;
 }
 
@@ -566,8 +561,8 @@ static void Resize(w)
     Widget w;
 {
     LabelWidget lw = (LabelWidget)w;
-    Position dx, dy;
-    _Reposition(lw, w->core.width, w->core.height, &dx, &dy);
+
+    _Reposition(lw, w->core.width, w->core.height);
     compute_bitmap_offsets (lw);
 }
 
@@ -655,8 +650,8 @@ static Boolean SetValues(current, request, new, args, num_args)
     if ((curlw->label.internal_width != newlw->label.internal_width) ||
         (curlw->label.internal_height != newlw->label.internal_height) || was_resized) {
 	/* Resize() will be called if geometry changes succeed */
-	Position dx, dy;
-	_Reposition(newlw, curlw->core.width, curlw->core.height, &dx, &dy);
+
+	_Reposition(newlw, curlw->core.width, curlw->core.height);
     }
 
     return was_resized || redisplay ||
