@@ -462,8 +462,9 @@ static void Initialize( request, new, args, num_args )
  ***********************************************************************/
 
 static void Realize (w, valueMask, attributes)
-    Widget w;
-    XSetWindowAttributes *attributes;
+Widget w;
+Mask *valueMask;
+XSetWindowAttributes *attributes;
 {
     /* 
      * The Simple widget actually stuffs the value in the valuemask. 
