@@ -60,9 +60,6 @@ SOFTWARE.
 #include <X11/Xos.h>		/* for O_RDONLY */
 #include <errno.h>
 
-extern int errno, sys_nerr;
-extern char* sys_errlist[];
-
 #define INSERT_FILE ("Enter Filename:")
 
 #define SEARCH_LABEL_1  ("Use <Tab> to change fields.")
